@@ -33,7 +33,7 @@ LOG_PATH: str = "/var/log/comitup.log"
 log: Optional[logging.Logger] = None
 
 
-def deflog(verbose: bool) -> logging.Logger:
+def deflog(verbose: int) -> logging.Logger:
     level = logging.INFO
     if verbose:
         level = logging.DEBUG
@@ -131,12 +131,15 @@ def main():
         sys.exit(0)
 
     if args.check:
-        if wificheck.run_checks():
+        if wificheck.run_checks(primary_dev=conf.primary_wifi_device):
             sys.exit(1)
         else:
             sys.exit(0)
     else:
-        wificheck.run_checks(verbose=False)
+        wificheck.run_checks(
+            verbose=False,
+            primary_dev=conf.primary_wifi_device,
+        )
 
     check_environment(log)
 
